@@ -317,16 +317,7 @@ display_gui (void)
   /* Move the grabs to our message box */
   gdk_pointer_grab (box->window, TRUE, 0,
 		    NULL, NULL, GDK_CURRENT_TIME);
-  gdk_keyboard_grab (invisible->window, FALSE, GDK_CURRENT_TIME);
-
-  /* Hmm, I suppose that it's a bug, or strange behaviour on gnome-dialog's
-   * part that even though the Yes is the default, Help somehow gets focus
-   * and thus temporairly grabs default as well.  I dunno if this should be
-   * changed in gnome-dialog, as grabbing the focus in _set_default would
-   * also be wrong.  Hmm, there should be a _set_focus as well I suppose,
-   * anyway, this will work */
-  if (GTK_WINDOW (box)->default_widget != NULL)
-	  gtk_widget_grab_focus (GTK_WINDOW (box)->default_widget);
+  gdk_keyboard_grab (box->window, FALSE, GDK_CURRENT_TIME);
 
   response = gtk_dialog_run (GTK_DIALOG (box));
 
